#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IF_ELSE_ZERO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IF_ELSE_ZERO_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/simd/if_else_zero.hpp>

#endif
